==> rGREAT_1.16.1.zip: rGREAT/doc/rGREAT.R <==
## ---- echo = FALSE, message = FALSE---------------------------------------------------------------
library(knitr)
knitr::opts_chunk$set(
    error = FALSE,
    tidy  = FALSE,
    message = FALSE,
    fig.align = "center")
options(width = 100)
options(markdown.HTML.stylesheet = "custom.css")

## ---- echo = 2------------------------------------------------------------------------------------
suppressWarnings(suppressPackageStartupMessages(library(rGREAT)))
library(rGREAT)

## -------------------------------------------------------------------------------------------------
set.seed(123)
bed = circlize::generateRandomBed(nr = 1000, nc = 0)
bed[1:2, ]

## -------------------------------------------------------------------------------------------------
job = submitGreatJob(bed)

## -------------------------------------------------------------------------------------------------
job

## ---- eval = FALSE--------------------------------------------------------------------------------
#  job = submitGreatJob(bed, species = "mm9")
#  job = submitGreatJob(bed, bg, species = "mm9")
#  job = submitGreatJob(bed, adv_upstream = 10, adv_downstream = 2, adv_span = 2000)
#  job = submitGreatJob(bed, rule = "twoClosest", adv_twoDistance = 2000)
#  job = submitGreatJob(bed, rule = "oneClosest", adv_oneDistance = 2000)

## ---- eval = FALSE--------------------------------------------------------------------------------
#  job = submitGreatJob(bed, version = "3.0")
#  job = submitGreatJob(bed, version = "2.0")

## -------------------------------------------------------------------------------------------------
tb = getEnrichmentTables(job)
names(tb)
tb[[1]][1:2, ]

## -------------------------------------------------------------------------------------------------
job

## ---- eval = FALSE--------------------------------------------------------------------------------
#  tb = getEnrichmentTables(job, ontology = c("GO Molecular Function", "BioCyc Pathway"))
#  tb = getEnrichmentTables(job, category = c("GO"))

## -------------------------------------------------------------------------------------------------
availableOntologies(job)
availableCategories(job)
availableOntologies(job, category = "GO")

## ---- fig.width = 10, fig.height = 10/3, fig.align = 'center'-------------------------------------
res = plotRegionGeneAssociationGraphs(job)
res[1:2, ]

## ---- eval = FALSE--------------------------------------------------------------------------------
#  plotRegionGeneAssociationGraphs(job, type = 1)

## ---- fig.width = 10, fig.height = 10/3-----------------------------------------------------------
res = plotRegionGeneAssociationGraphs(job, ontology = "GO Molecular Function",
    termID = "GO:0004984")
res[1:2, ]

## -------------------------------------------------------------------------------------------------
sessionInfo()

==> rGREAT_1.24.0.zip: rGREAT/doc/rGREAT.R <==
## ---- echo = FALSE, message = FALSE---------------------------------------------------------------
library(knitr)
knitr::opts_chunk$set(
    error = FALSE,
    tidy  = FALSE,
    message = FALSE,
    fig.align = "center")
options(width = 100)
options(markdown.HTML.stylesheet = "custom.css")

## ---- echo = 2------------------------------------------------------------------------------------
suppressWarnings(suppressPackageStartupMessages(library(rGREAT)))
library(rGREAT)

## -------------------------------------------------------------------------------------------------
set.seed(123)
bed = circlize::generateRandomBed(nr = 1000, nc = 0)
bed[1:2, ]

## -------------------------------------------------------------------------------------------------
job = submitGreatJob(bed)

## -------------------------------------------------------------------------------------------------
job

## ---- eval = FALSE--------------------------------------------------------------------------------
#  job = submitGreatJob(bed, species = "mm9")
#  job = submitGreatJob(bed, bg, species = "mm9")
#  job = submitGreatJob(bed, adv_upstream = 10, adv_downstream = 2, adv_span = 2000)
#  job = submitGreatJob(bed, rule = "twoClosest", adv_twoDistance = 2000)
#  job = submitGreatJob(bed, rule = "oneClosest", adv_oneDistance = 2000)

## ---- eval = FALSE--------------------------------------------------------------------------------
#  job = submitGreatJob(bed, version = "3.0")
#  job = submitGreatJob(bed, version = "2.0")

## ---- message = TRUE------------------------------------------------------------------------------
tb = getEnrichmentTables(job)
names(tb)
tb[[1]][1:2, ]

## -------------------------------------------------------------------------------------------------
job

## ---- eval = FALSE--------------------------------------------------------------------------------
#  tb = getEnrichmentTables(job, ontology = c("GO Molecular Function", "BioCyc Pathway"))
#  tb = getEnrichmentTables(job, category = c("GO"))

## ---- message = TRUE------------------------------------------------------------------------------
tb2 = getEnrichmentTables(job, download_by = "tsv")
nrow(tb2[["GO Molecular Function"]])
head(tb2[["GO Molecular Function"]])

## -------------------------------------------------------------------------------------------------
availableOntologies(job)
availableCategories(job)
availableOntologies(job, category = "GO")

## ---- fig.width = 10, fig.height = 10/3, fig.align = 'center'-------------------------------------
res = plotRegionGeneAssociationGraphs(job)
res[1:2, ]

## ---- eval = FALSE--------------------------------------------------------------------------------
#  plotRegionGeneAssociationGraphs(job, type = 1)

## ---- fig.width = 10, fig.height = 10/3-----------------------------------------------------------
res = plotRegionGeneAssociationGraphs(job, ontology = "GO Molecular Function",
    termID = "GO:0004984")
res[1:2, ]

## -------------------------------------------------------------------------------------------------
sessionInfo()
